@@ -41,6 +41,7 @@ def build_and_schedule(gantt_name: str,
                        project_priority: Dict = None,
                        schedule_start_date: date = None,
                        schedule_method: ScheduleMethod = None,
+                       defined_schedule_sequence: Dict = None,
                        output_dirs: List[str] = None):
 
     gantt = Gantt.gantt_from_listdict(name=gantt_name, tasks_listdict=gantt_task_data, resources_dict={r.name: r for r in resources})
@@ -50,7 +51,8 @@ def build_and_schedule(gantt_name: str,
     gantt.calculate_schedule(schedule_start_date,
                              max_resources_per_project=resource_max_by_project,
                              project_priority=project_priority,
-                             schedule_method=schedule_method)
+                             schedule_method=schedule_method,
+                             defined_schedule_sequence=defined_schedule_sequence)
 
 
     #Output
@@ -118,13 +120,16 @@ if __name__ == "__main__":
     tasks = read_data_file(ganttTasksCsvFilePath)
     resources = read_resource_file(resourceFileCsvFilePath)
 
+    defined_schedule_sequence = {x['id']: ii for ii, x in enumerate(tasks)}
+
     chart = build_and_schedule(gantt_name=ganttTasksCsvFilePath,
                                gantt_task_data=tasks,
                                resources=resources,
-                               resource_max_by_project = resource_max_by_project,
-                               project_priority= project_priority,
-                               schedule_method=ScheduleMethod.EARLIEST_DUE_DATE,
-                               output_dirs = [
+                               resource_max_by_project=resource_max_by_project,
+                               project_priority=project_priority,
+                               schedule_method=ScheduleMethod.DEFINED_SEQUENCE,
+                               defined_schedule_sequence=defined_schedule_sequence,
+                               output_dirs=[
                                    './gantt_items_scheduled.csv'
                                ])
 
