@@ -6,7 +6,8 @@ class ScheduleMethod(Enum):
     CRITICAL_RATIO = 3,
     SLACK_PER_REMAINING_OPERATIONS = 4,
     SHORTEST_PROCESSING_TIME = 5,
-    FIRST_COME_FIRST_SERVED = 6
+    FIRST_COME_FIRST_SERVED = 6,
+    DEFINED_SEQUENCE = 7
 
 class ActivityStatus(Enum):
     ToDo = 1,
