@@ -372,27 +372,40 @@ class Gantt:
                            start_date,
                            max_resources_per_project: Dict[str, Dict[str, int]] = None,
                            project_priority: Dict[str, int] = None,
-                           schedule_method: ScheduleMethod = None):
+                           schedule_method: ScheduleMethod = None,
+                           defined_schedule_sequence: Dict[str, int] = None):
         """
         Calculates the start and end dates of each task. Do activities with actual dates prior to w.o actual dates.
         This prevents the algo from assigning a resource that is committed to a task with an actual date simply because
         it was provided first
+
+        :param: schedule_method ScheduleMethod: defines how the scheduling algorithm will behave. Different types result
+        in different schedules based on the user's prioritization concerns
+
+        :param defined_schedule_sequence Dict[wi_id: str, sequence: int]: necessary if the schedule_method is
+        ScheduleMethod.DEFINED_SEQUENCE. Defines the sequence in which to perform the scheduling routine. Note that if
+        an item is a predecessor of an item with an earlier sequence, the predecessor relationship will still be honored.
+        Tasks without values in the defined_schedule_sequence will be scheduled last and in project_priority order.
+        Final sort order is FIFO
         """
 
+        # start by honoring any task with an actual_start_date
         self.set_schedule_for_activities_with_actual_start(start_date)
 
-
+        # Default to ScheduleMethod.PRIORITY
         if schedule_method is None:
             schedule_method = ScheduleMethod.PRIORITY
 
+        # Switch on ScheduleMethod
         if schedule_method == ScheduleMethod.PRIORITY:
             self.schedule_by_priority(start_date, max_resources_per_project, project_priority)
         elif schedule_method == ScheduleMethod.EARLIEST_DUE_DATE:
             self.schedule_by_earliest_due_date(start_date, max_resources_per_project, project_priority)
+        elif schedule_method == ScheduleMethod.DEFINED_SEQUENCE:
+            self.schedule_by_defined_sequence(start_date, defined_schedule_sequence, max_resources_per_project, project_priority)
         else:
             raise NotImplementedError(f"The provided schedule method [{schedule_method}] is not understood for scheduling")
 
-
         # Raise error if any task ends up not scheduled
         shouldnt_be_left = self.activities_not_scheduled
         if any(shouldnt_be_left):
@@ -459,14 +472,53 @@ class Gantt:
         if project_priority is None:
             project_priority = {}
 
+        # Get all items not scheduled (only scheduled should be items with actual_start_date
         needs_scheduled = self.activities_not_scheduled
 
         #Multiply the task priority by the project priority for an "Overall" priority
         needs_scheduled.sort(key=lambda x: x.extrapolated_priority * project_priority.get(x.project.name, 10))
 
+        # Schedule remaining
         for item in needs_scheduled:
             item.schedule(start_date, max_resources_per_project.get(item.project.name, None))
 
+    def schedule_by_defined_sequence(self,
+                             start_date,
+                             defined_schedule_sequence: Dict[str, int],
+                             max_resources_per_project: Dict[str, Dict[str, int]] = None,
+                             project_priority: Dict[str, int] = None,
+                            ):
+        if defined_schedule_sequence is None:
+            raise ValueError(f"the parameter defined_schedule_sequence cannot be None when scheduling using ScheduleMethod.DEFINED_SEQUENCE")
+
+        if project_priority is None:
+            project_priority = {}
+
+        # Get all items not scheduled (only scheduled should be items with actual_start_date
+        needs_scheduled = self.activities_not_scheduled
+
+        # Sort needs scheduled first by presence of a value in defined_schedule_sequence, then by that value (None's last)
+        # Note: Sorting by a Tuple. False<True. key=lambda x: (x is None, x)  --> https://stackoverflow.com/questions/18411560/python-sort-list-with-none-at-the-end
+        needs_scheduled.sort(key=lambda x: (defined_schedule_sequence.get(x, None) is None, defined_schedule_sequence.get(x, None)))
+
+        # Schedule items in defined_schedule order. Will also appropriately schedule pre-decessors
+        for item in needs_scheduled:
+            # Once hit None's, done scheduling according to definition
+            if defined_schedule_sequence.get(item, None) is None:
+                break
+            item.schedule(start_date, max_resources_per_project.get(item.project.name, None))
+
+        # Get remaining tasks left unscheduled
+        remaining_unscheduled = self.activities_not_scheduled
+
+        # Sort by priority (Multiply by project priority)
+        remaining_unscheduled.sort(key=lambda x: x.priority * project_priority.get(x.project.name, 10))
+
+        # Schedule remaining
+        for item in needs_scheduled:
+            item.schedule(start_date, max_resources_per_project.get(item.project.name, None))
+
+
     def to_csv(self, filepath: str):
         with open(filepath, 'a+') as file:
             for task in self.tasks:
